Extract point estimate of model coefficients
extract_coefficients.RdGiven posterior draws from a brms model or projpred projection and scaling values for predictors, converts coefficients from scaled predictors to the original variable scale and returns summary statistics.
Arguments
- mod
Model object or posterior draws compatible with
posterior::as_draws_matrix().- scls
Scaling values as exported by
fit_reference.- stat
Summary statistic applied to posterior draws.
- ...
Unused. There to allow for compatibility with
run_scoring_rule_pipeline.