Fit a grid of reference models
grid_models.RdUsing different values of "gold standard" measures of the outcome and number
of expected non-zero parameters, fits a set of reference models via
fit_reference.
Usage
grid_models(
d,
gss = c("Lvl.II (1)", "Lvl.II (2)"),
N = 5,
n_chosen = NA,
bind = FALSE,
...
)Arguments
- d
Input data, e.g., generated by
diagnose_pdd_sample.- gss
Gold standard variables.
- N
Vector of expected non-zero coefficient for a regularised horseshoe prior.
- n_chosen
Number of selected parameters.
- bind
Should all combinations of
gssandNbe found (FALSE) or should they be simply binded (TRUE)- ...
Other parameters for
fit_reference().
Value
A list with four components:
- grid
A grid of input values.
- reference
List of reference models.
- vs_object
List of variable selection results
- vs_plots
Plots visualising variable selection
- projection
List of selected models projected onto appropriate reference model
See also
fit_reference()for reference model fittingperform_varsel()for variable selection implementationprojpred::project()for projective prediction implementation